@@ -5,8 +5,8 @@ from __future__ import annotations
 from typing import Iterator
 
 import pytest
+from _griffe.docstrings import google, numpy, sphinx
 
-from griffe.docstrings import google, numpy, sphinx
 from tests.test_docstrings.helpers import ParserType, parser
 
 
