@@ -8,9 +8,7 @@ from typing import TYPE_CHECKING
 
 import pytest
 
-from griffe.cli import check
-from griffe.dataclasses import Module
-from griffe.loader import load_git
+from griffe import Module, check, load_git
 from tests import FIXTURES_DIR
 
 if TYPE_CHECKING:
